@@ -15,10 +15,8 @@
 # You should have received a copy of the GNU General Public License
 # along with Ansible.  If not, see <http://www.gnu.org/licenses/>.
 
-# Make coding more python3-ish
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-__version__ = '2.14.18'
+__version__ = '2.19.1'
 __author__ = 'Ansible, Inc.'
-__codename__ = "C'mon Everybody"
+__codename__ = "What Is and What Should Never Be"
